function [acf,xn] = acf_denoise(Nx,N,SNR)
% function [acf,xn] = acf_denoise(Nx,N,SNR)
%
% use acf for denoisung of sinusiod
%
% Nx   signal length
% N    period od sinusoid
% SNR  signal-to-noise ration in dB
% acf  acf of noisy signal    
% xn   noisy signal
%
% (c) 2000 G. Doblinger, TU-Wien

if nargin == 0
   help acf_denoise
   return
end

% create noise sinusoid

Nx = max(Nx,N);
n = [0:Nx-1];
x = sin(2*pi/N*n);
r = randn(size(x));
R = norm(x)/norm(r);              % actual SNR
xn = x + R*10^(-SNR/20)*r;        % add noise with given SNR 

% compute acf (unbiased estimate)

acf = conv(xn(end:-1:1),xn);
acf = Nx./(Nx-n) .* acf(Nx:end);  % correct triangular window
%acf = acf(Nx:end);                % biased estimate

% measure period of sinusoid by counting zero crossings

d = acf > 0;
diff = d - [0 d(1:end-1)];
idp = find(diff > 0); 
idm = find(diff < 0); 
i1 = idp(2:2:end-2);
i2 = idp(3:2:end-1);
Np = sum(i2-i1)/length(i1);
disp(['estimated period = ',int2str(Np)]);

