function envelope(x,M)
% function envelope(x,M)
% decimated signal display by plotting min. and max. of blocks of M samples
% using area function for colored area between min/max curves
%
% G. Doblinger, TU-Wien, 11-2000
   
if nargin == 0
   help envelope;
   return;
end
[nr,nc] = size(x);
if (nr ~= 1) & (nc ~= 1)
   error('signal must be a vector');
end   
ndata = max(nr,nc);
nblocks = floor(ndata/M);           % number of blocks of length M
ndata = M * nblocks;                % make ndata divisible by M

X = zeros(M,nblocks);
X(:) = x(1:ndata);                  % each column of X contains a block
                                    % of M consecutive samples
xmax = max(X);
xmin = min(X);
				    
close all
upperleft = [0 0.6 0.49 0.4];
fsig = figure('name','Compact signal display (x_zoom on)','Units','normal','Position',upperleft);
colordef(fsig,'black');
t = 0:nblocks-1;
%plot(t,xmax,'y',t,xmin,'y');       % simple display
hold on, area(t,xmax), area(t,xmin), hold off   % more advanced display
axis([0 nblocks-1 1.1*min(xmin) 1.1*max(xmax)]);
colormap([0 0.6 1]); 
xlabel('Decimated time index'), ylabel('Amplitude');
title(['Signal envelope plot, decimation factor M = ',int2str(M)]);
grid on;
zoom(fsig,'xon');
