function y = blackbox(systype,x)
% function y = blackbox(systype,x)
%
% compute response of various blackbox discrete-time systems to input
% signal given for time indices n >= 0
%
% systype   integer 1 ... 10 to select one of 10 implemented systems
% x         vector of input signal samples for time indices n >= 0
% y         column vector of output signal samples (n >=0)
%
% G. Doblinger, TU-Wien, 12-92

if nargin == 0
   help blackbox
   return
elseif nargin ~= 2
   error('BLACKBOX: wrong number of arguments')
end
N = max(size(x));
if min(size(x)) > 1
   error('BLACKBOX: input signal must be a vector')
end
x = x(:);
if     systype == 1,    y = 2 * x + 0.5;
elseif systype == 2,    y = filter(fir1(28,0.25),1,x);
elseif systype == 3,    y = filtfilt(1,[1 -0.8],x);
elseif systype == 4,    y = filter(1,[1 -0.9],x,0.5);
elseif systype == 5,    y = [0 ; x(1:N-1).*x(2:N)];
elseif systype == 6,    y = [x(1) ; x(2:N)-x(1:N-1)];
elseif systype == 7,    y = [0:N-1]' .* x;
elseif systype == 8,    y(1:2:N) = x(1:2:N);       
                        y(2:2:N) = -x(2:2:N);
elseif systype == 9,    y = filter([1 1 1 1 1],1,x);      
                        ip = find(y > 1);
                        in = find(y < -1);
                        if ~isempty(ip), y(ip) = ones(size(ip)); end
                        if ~isempty(in), y(in) = -ones(size(in)); end
elseif systype == 10,   y = filtfilt([1 -1 1 -1 1],1,x);      
end
