function [A,B,C,D] = tf2blockss(b,a,M)
%function [A,B,C,D] = tf2blockss(b,a,M)
%
% compute block state-space decomposition
%
% b,a   numerator and denominator coefficients of
%       filter transfer function
% M     block size
%
% G. Doblinger, 12-2000, TU-Wien
%

if nargin == 0
   help tf2blockss
   return
end

N = max(length(a),length(b))-1;
[A1,B1,C1,D1] = tf2ss(b,a);

B = zeros(N,M);
C = zeros(M,N);
Ap = 1;
for n = M-1:-1:1
   Ap = Ap*A1;
   B(:,n) = Ap*B1;
   C(M-n+1,:) = C1*Ap;
end
A = Ap*A1;
B(:,M) = B1;
C(1,:) = C1;
D = toeplitz([D1 ; C(1:M-1,:)*B1],[D1 zeros(1,M-1)]);


