function [ylin,ycyc] = convolve(x1,x2)
% function [ylin,ycyc] = convolve(x1,x2)
%
% compute linear and cyclic convolution of two sequences using FFT
%
% x1     signal vector 1 with length N1
% x2     signal vector 2 with length N2
% ylin   column vector of linear convolution result (length N1 + N2 - 1)
% ycyc   column vector of cyclic convolution result (length max(N1,N2))
%
% copyright (c) G. Doblinger, TU-Wien, 12-92

if nargin == 0
   help convolve
   return
end

N1 = max(size(x1)); N2 = max(size(x2)); N = max(N1,N2);
ylin = ifft(fft([x1(:) ; zeros(N2-1,1)]) .* fft([x2(:) ; zeros(N1-1,1)])); 
ycyc = ifft(fft([x1(:) ; zeros(N-N1,1)]) .* fft([x2(:) ; zeros(N-N2,1)])); 

if ~any(imag(x1)) & ~any(imag(x2))
   ylin = real(ylin);   ycyc = real(ycyc);
end
