function dft_compare(N,xtyp)
% function dft_compare(N,xtyp)
%
% compare speed and precision of DFT and FFT
%
% N      DFT length
% xtyp   0 (default) white gaussian noise input 
%        1           sinusoidal input signal
%
% G. Doblinger, 12-2000, TU-Wien

if nargin == 0
   help dft_compare
   return
elseif nargin == 1
   xtyp = 0;
end

if xtyp == 0
   x = randn(N,1);
   disp('white gaussian noise input signal');
else
   x = sin(2*pi/N*10*[0:N-1]');
   disp('sinusoidal input signal');
end

% compute DFT and IDFT

t0 = clock;
n = 0:N-1;
W = exp(-j*2*pi/N*n);
Xd = zeros(N,1);
for k = 0:N-1
   m = rem(n*k,N)+1;
   Xd(k+1) = W(m)*x;
end
W = 1/N*conj(W);
xd = zeros(N,1);
for k = 0:N-1
   m = rem(n*k,N)+1;
   xd(k+1) = W(m)*Xd;
end
E= max(abs(xd-x));
T = etime(clock,t0);
disp(sprintf('DFT+IDFT: exec. time = %2.2e sec., max. error = %2.2e',...
	     T, E));
t0 = clock;
xd = ifft(fft(x));
E = max(abs(xd-x));
T = etime(clock,t0);
disp(sprintf('FFT+IFFT: exec. time = %2.2e sec., max. error = %2.2e',...
	     T, E));
