% script to design FIR filters with prescribed delay response
% (chirp allpass filter)
% based on m-files of M. Langs PHD thesis
% G. Doblinger, 12-2000, TU-Wien

N = 61;
Nd = (N-1)/2;
%beta = 8/(2*pi);
beta = 16/(2*pi);
L = 10*N;
theta = pi*linspace(0,1,L);
W = ones(1,L);
phi = -Nd*theta - beta*(theta-pi/2).^2;
D = exp(j*phi);
t0 = clock;
h = lslevin(N,theta,D,W);
%h = lawson(N,theta,D,W,25);
disp(sprintf('execution time of LSLEVIN = %f sec.',etime(clock,t0)));

Nf = 2048;
f = linspace(0,1,Nf);
H = freqz(h,1,Nf);
HdB = 20*log10(abs(H) + eps);
ph = unwrap(angle(H));
Tg = -Nf / pi * diff(ph) - Nd;     % Tg in samples

close all
if strcmp(upper(computer),'PCWIN')
   pos1 = [0.5 0.5 0.49 0.415];
else	
   pos1 = [0.5 0.6 0.49 0.4];
end

ftime = figure('numbertitle','off','name','Time domain','Units','normal','Position',pos1);
colordef(ftime,'black');

n = 0:N-1;
if N <= 120
   discret(n,h);
else
   plot(n,h); grid on;
end
ylabel('h(n)');
title(['FIR filter (LSLEVIN alg.), N = ', int2str(N)]);

pos1(1) = pos1(1) - 0.495;
fmag = figure('numbertitle','off','name','Frequency domain (y-zoom on)',...
   'Units','normal','Position',pos1);
colordef(fmag,'black');

subplot(2,1,1), plot(f,HdB), grid on;
ylabel('Magnitude in dB');
axis([0 1 -0.01 0.01]);
subplot(2,1,2), plot(f(1:Nf-1),Tg), grid on;
xlabel('Frequency normalized to Fs/2');
ylabel('norm. \tau_g in samples');
zoom(fmag,'yon');
