function [h,Hid] = firfs(N,fc)
% function [h,Hid] = firfs(N,fc)
%
% purpose: FIR filter design by frequency sampling (linear phase, low pass
%          filter design)
% call:    [h,Hid] = firfs(N,fc)
%
% N   filter length (number of frequency samples)
% fc  cutoff frequency normalized to Fs/2
% h   impulse response
% Hid frequency response at N frequency points
%
% G. Doblinger, TU-Wien, 7-1994

if nargin == 0
   help firfs
   return
end

% create ideal low pass filter magnitude response

N2 = fix((N-1)/2);
Np = fix(fc*N/2);
Hmag = zeros(1,N);
Hmag(1:Np+1) = ones(1,Np+1);        % magnitude response from 0 to pi
                                    % (ideal low pass filter)
Hmag(N-N2+1:N) = Hmag(N2+1:-1:2);   % magnitude response from pi to 2*pi, using
                                    % (even) symmetry property 
 
% create linear phase response

phi = zeros(1,N);
phi(1:N2+1) = -pi*(N-1)*(0:N2)/N;   % phase response from 0 to pi   
phi(N-N2+1:N) = -phi(N2+1:-1:2);    % phase response from pi to 2*pi, using
                                    % (odd) symmetry property   

% compute ideal frequency response, and FIR filter impulse response
                                    
Hid = Hmag .* exp(j*phi);
h = real(ifft(Hid));
   
