function h = firrem(fc,fr,ar,rp,N)
% function  h = firrem(fc,fr,ar,rp,N)
%
% purpose: optimum design of linear-phase FIR lowpass filter using remez()
% call:    h = firrem(fc,fr,ar,rp) or  h = firrem(fc,fr,ar,rp,N)
%
% fc  passband edge frequeny normalized to Fs/2
% fr  stopband edge frequeny normalized to Fs/2
% ar  stopband attenuation in dB
% rp  passband ripple in dB
% N   optional filter length (if omitted, then estimated filter length is used)
%
% G. Doblinger, TU-Wien, 08-1994

if nargin == 0
   help firrem
   return
end
if max(fc,fr) > 1
   error('FIRREM: frequency must be normalized to Fs/2');
elseif fc > fr
   error('FIRREM: passband edge > stopband edge');
end

% compute ripples (linear scale)
   
d2 = 10^(-ar/20);
rpl = 10^(rp/20);
d1 = (rpl-1)/(rpl+1);
w = d1/d2;

% estimate filter length

if nargin == 4
   N = 1 + ceil((-10*log10(d1*d2)-13)/(7.3*(fr-fc)));
end

% compute impulse response (emphasize stop band using weighting factor w)

h = remez(N-1,[0,fc,fr,1],[1,1,0,0],[1,w]);

