function h = firsym(N,fc,even_odd)
% function h = firsym(N,fc,even_odd)
%
% purpose: demonstrate symmtry properties of linear phase FIR lowpass filter
% call: h = firsym(N,fc,even_odd)
%
% N         filter length
% fc        cutoff frequency normalized to Fs/2
% even_odd  'e' for impulse response with even symmetry, 'o' for odd symmetry
% h         impulse response vector
%
% G. Doblinger, TU-Wien, 8-94

if nargin == 0
   help firsym
   return
elseif fc > 1
   error('FIRSYM: fc must be less than 1');
end   

N2 = fix(N/2);
if rem(N,2) == 1
   n = pi*[1:N2];
   h = sin(fc*n)./n;
   if strcmp(even_odd,'e')
      h = [h(N2:-1:1),fc,h];
   else
      h = [-h(N2:-1:1),0,h];
   end
else
   n = pi*([1:N2] - 0.5);
   h = sin(fc*n)./n;
   if strcmp(even_odd,'e')
      h = [h(N2:-1:1),h];
   else
      h = [-h(N2:-1:1),h];
   end
end

