function h_min = lin2min(h_lin)
% function h_min = lin2min(h_lin)
%
% compute minimum phase FIR filter by inverting zeros outside unit
% circle of linear phase FIR filter 
%
% h_lin  impulse response vector of linear phase FIR filter
% h_min  impulse response vector of respective minimum phase FIR filter
%
% G. Doblinger, TU-Wien, 7-1994

if nargin == 0
   help lin2min
   return
end

z = roots(h_lin);
iout = find(abs(z) > 1);
if ~isempty(iout)
   z(iout) = 1 ./ conj(z(iout));    % invert zeros outside unit circle   
end

h_min = real(poly(z));
sh = sum(h_lin);
if abs(sh) > 0                      % scale h_min to |H_min(0)| = 1
   scal = sh/sum(h_min);
   h_min = h_min * scal;
end
