% script to compare low delay FIR filters
% based on m-files of M. Langs doctoral thesis
% G. Doblinger, 12-2000, TU-Wien

N = 101;
Ndoff = -20;
delay = (N-1)/2 + Ndoff;
Npass = 10*N;
Nstop = 10*N;
fc = 2/8;
fr = 2.5/8;
Wpass = 1;
Wstop = 50;
Wstopc = 3;
om = pi*[linspace(0,fc,Npass), linspace(fr,1,Nstop)];
w = [Wpass*ones(1,Npass), Wstop*ones(1,Nstop)]; 
wc = [Wpass*ones(1,Npass), Wstopc*ones(1,Nstop)]; 
D = [exp(-j*om(1:Npass)*delay) zeros(1,Nstop)];
t0 = clock;
h = lslevin(N,om,D,w);
disp(sprintf('execution time of LSLEVIN = %f sec.',etime(clock,t0)));
t0 = clock;
%hc = cremez(N-1,[0 fc fr 1],{'lowpass',Ndoff});
hc = lawson(N,om,D,wc,25);
%hc = burnpark(N,om,D,w);
disp(sprintf('execution time of LAWSON = %f sec.',etime(clock,t0)));

%hr = remez(N-1,[0 fc fr 1],[1 1 0 0],[Wpass Wstopc]);

Nf = 2048;
f = linspace(0,1,Nf);
H = freqz(h,1,Nf);
HdB = 20*log10(abs(H) + eps);
ph = unwrap(angle(H));
Tg = -Nf / pi * diff(ph);     % Tg in samples

Hc = freqz(hc,1,Nf);
HdBc = 20*log10(abs(Hc) + eps);
ph = unwrap(angle(Hc));
Tgc = -Nf / pi * diff(ph); 

close all
if strcmp(upper(computer),'PCWIN')
   pos1 = [0.5 0.5 0.49 0.415];
   axfnt = 9;
   ticfnt = 7;
else	
   pos1 = [0.5 0.6 0.49 0.4];
   axfnt = 10;
   ticfnt = 9;
end

ftime = figure('numbertitle','off','name','Time domain','Units','normal','Position',pos1);
colordef(ftime,'black');

n = 0:N-1;
if N <= 120
   discret(n,h);
else
   plot(n,h); grid on;
end
hx = xlabel('n'); hy = ylabel('h(n)');
ht = title(['FIR filter (LSLEVIN), N = ', int2str(N), ', delay = ',num2str(delay)]);
set(hy,'fontsize',axfnt);
set(hx,'fontsize',axfnt);
set(ht,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);

pos1(1) = pos1(1) - 0.495;
fmag = figure('numbertitle','off','name','Frequency domain (y-zoom on)',...
   'Units','normal','Position',pos1);
colordef(fmag,'black');

subplot(2,1,1), plot(f,HdB,f,HdBc), grid on;
ht = title('LSLEVIN alg. (y), LAWSON alg. (m)'); 
hy = ylabel('|H(f)|   (dB)'); hx = xlabel('f');
set(hy,'fontsize',axfnt);
set(hx,'fontsize',axfnt);
set(ht,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);
axis([0 1 -100 20]);
Nc = max(find(f <= fc));
subplot(2,2,3), plot(f(1:Nc),HdB(1:Nc),f(1:Nc),HdBc(1:Nc)), grid on;
hx = xlabel('f'); hy = ylabel('|H(f)|   (dB)');
set(hy,'fontsize',axfnt);
set(hx,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);
axis([0 fc -inf inf]);
subplot(2,2,4), plot(f(1:Nc),Tg(1:Nc),f(1:Nc),Tgc(1:Nc)), grid on;
hx = xlabel('f'); hy = ylabel('\tau   (Samples)');
set(hy,'fontsize',axfnt);
set(hx,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);
axis([0 fc -inf inf]);
zoom(fmag,'yon');
