function nufdemo(opt)
%
% nonuniform filter bank design example (guided tour)
% (different transition widths of filter bank sections)
%
% opt   0 or omitted for iterative linear equation solving
%       1 for nonlinear optimization using fminunc()
%
% (c) copyright 8-1996, Th. Zeitlhofer, G.Doblinger, TU-Wien
%

if nargin == 0
   opt = 0;
end

disp('**********************************************************************');
disp('*                                                                    *');
disp('*                            DEMONSTRATION                           *');
disp('*                                                                    *');
disp('*                  How to use "unicmfb" and "nuftrans"               *');
disp('*                 for a non-uniform filterbank design.               *');
disp('*                    (different transition widths)                   *');
disp('*                                                                    *');
disp(sprintf('**********************************************************************\n'));

disp('Example:');
disp(sprintf('\t 6-channel filterbank (2 uniform sections,1 transition filter)'));
disp(sprintf('\t section 1: bandwidth = pi/8'));
disp(sprintf('\t section 2: bandwidth = pi/4\n'));
disp(sprintf('\t H(f)       transition filter'));
disp(sprintf('\t |                  |       '));
disp(sprintf('\t |   section 1      |  section 2'));
disp(sprintf('\t |       |          |      |'));
disp(sprintf('\t | ______V______   _V__   _V__'));
disp(sprintf('\t |/             \\ /    \\ /    \\'));
disp(sprintf('\t |___ ___ ___ ___ ______ ______'));
disp(sprintf('\t | 1 | 1 | 1 | 1 |  1   |  1   |'));
disp(sprintf('\t | - | - | - | - |  -   |  -   |'));
disp(sprintf('\t | 8 | 8 | 8 | 8 |  4   |  4   |       '));
disp(sprintf('\t |---|---|---|---|------|------|---> fo'));
disp(sprintf('\t 0                             1       '));
disp(sprintf('\n\t fo ... frequency normalized to half the sampling frequency\n\n'));

disp(' *** PRESS A KEY TO CONTINUE ***'), pause
disp(sprintf('1.) computing prototype filter for section 1 using "unicmfb" :\n'));
disp(sprintf('>>h1=unicmfb(8,96,1/16,5e3,96);'));
[h1 Ha1 Hs1]=unicmfb(8,96,1/16,5e3,96);
disp(' *** PRESS A KEY TO CONTINUE ***'), pause
disp(sprintf('\n\n2.) computing prototype filter for section 2 using "unicmfb" :\n'));
disp(sprintf('>>h2=unicmfb(4,40,1/8,2e3,40);'));
[h2 Ha2 Hs2]=unicmfb(4,40,1/8,2e3,40);
disp(' *** PRESS A KEY TO CONTINUE ***'), pause
disp(sprintf('\n\n3.) computing transition filter using "nuftrans" :\n'));
if opt == 0
   disp(sprintf('>>ht=nuftrans(''l'',h1,8,h2,4,88,1);'));
   ht=nuftrans('l',h1,8,h2,4,96,1);
else
   disp(sprintf('>>ht=nuftrans(''o'',h1,8,h2,4,88,1);'));
   ht=nuftrans('o',h1,8,h2,4,96,1);
end
disp(' *** PRESS A KEY TO CONTINUE ***'), pause

disp(sprintf('\n\n4.) Now we can analyze the resulting non-uniform filterbank.'));
disp(sprintf('>>nufplot(h1,8,h2,4,ht,4,0);'));

close all
nufplot(h1,8,h2,4,ht,4,0);
disp(' *** PRESS A KEY TO CONTINUE ***'), pause

disp(sprintf('\n\n5.) We can perform a frequency inversion'));
disp(sprintf('    by multiplying the channel impulse responses with (-1)^n'));
disp(sprintf('>>nufplot(h1,8,h2,4,ht,4,1);'));

close all
nufplot(h1,8,h2,4,ht,4,1);

disp('**********************************************************************');
disp('*                                                                    *');
disp('*                        END OF DEMONSTRATION                        *');
disp('*                                                                    *');
disp('**********************************************************************');
